@@ -12,6 +12,7 @@ def parse():
     # read in command line arguments
     parser = argparse.ArgumentParser(description='MKID Pipeline CLI')
     parser.add_argument('--init', action='store_true', help='launch the interface')
+    parser.add_argument('--dinit', action='store_true', help='launch the interface through docker')
     parser.add_argument('--outp', help='output destination', dest='out_cfg', default=None)
     parser.add_argument('--inp', help='data location', dest='in_cfg' , default=None)
     parser.add_argument('--format', help='format of the plot', default='.jpg', dest='form')
@@ -23,6 +24,9 @@ if __name__ == "__main__":
     args = parse()
 
     if args.init:
+        os.system("streamlit run Interface.py")
+
+    if args.dinit:
         os.system("streamlit run /tmp/Interface.py")
     
     if args.out_cfg!=None and args.in_cfg!=None:
